@@ -2,12 +2,12 @@
 
 import sys
 import json
-import argparse
 import singer
-from singer import metadata, utils
-from tap_mambu.client import MambuClient
-from tap_mambu.discover import discover
-from tap_mambu.sync import sync
+
+from tap_mambu.helpers.constants import DEFAULT_PAGE_SIZE
+from tap_mambu.helpers.client import MambuClient
+from tap_mambu.helpers.discover import discover
+from tap_mambu.sync import sync_all_streams
 
 LOGGER = singer.get_logger()
 
@@ -17,10 +17,8 @@ REQUIRED_CONFIG_KEYS = [
     'user_agent'
 ]
 
-DEFAULT_PAGE_SIZE = 500
 
 def do_discover():
-
     LOGGER.info('Starting discover')
     catalog = discover()
     json.dump(catalog.to_dict(), sys.stdout, indent=2)
@@ -29,7 +27,6 @@ def do_discover():
 
 @singer.utils.handle_top_exception(LOGGER)
 def main():
-
     parsed_args = singer.utils.parse_args(REQUIRED_CONFIG_KEYS)
 
     with MambuClient(parsed_args.config.get('username'),
@@ -47,10 +44,11 @@ def main():
         if parsed_args.discover:
             do_discover()
         elif parsed_args.catalog:
-            sync(client=client,
-                 config=parsed_args.config,
-                 catalog=parsed_args.catalog,
-                 state=state)
+            sync_all_streams(client=client,
+                             config=parsed_args.config,
+                             catalog=parsed_args.catalog,
+                             state=state)
+
 
 if __name__ == '__main__':
     main()
